@@ -1,9 +1,10 @@
 package resourcemerge
 
 import (
-	"k8s.io/apimachinery/pkg/util/intstr"
 	"testing"
 
+	"k8s.io/apimachinery/pkg/util/intstr"
+
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/equality"
 	"k8s.io/apimachinery/pkg/api/resource"
@@ -247,6 +248,117 @@ func TestEnsurePodSpec(t *testing.T) {
 				},
 			},
 		},
+		{
+			name: "remove a container",
+			existing: corev1.PodSpec{
+				Containers: []corev1.Container{
+					corev1.Container{Name: "test-A"},
+					corev1.Container{Name: "test-B"},
+				},
+			},
+			input: corev1.PodSpec{
+				Containers: []corev1.Container{
+					corev1.Container{Name: "test-B"},
+				},
+			},
+
+			expectedModified: true,
+			expected: corev1.PodSpec{
+				Containers: []corev1.Container{
+					corev1.Container{Name: "test-B"},
+				},
+			},
+		},
+		{
+			name: "add ports on container",
+			existing: corev1.PodSpec{
+				Containers: []corev1.Container{
+					corev1.Container{Name: "test"},
+				},
+			},
+			input: corev1.PodSpec{
+				Containers: []corev1.Container{
+					corev1.Container{
+						Name: "test",
+						Ports: []corev1.ContainerPort{
+							corev1.ContainerPort{ContainerPort: 8080},
+						},
+					},
+				},
+			},
+			expectedModified: true,
+			expected: corev1.PodSpec{
+				Containers: []corev1.Container{
+					corev1.Container{
+						Name: "test",
+						Ports: []corev1.ContainerPort{
+							corev1.ContainerPort{ContainerPort: 8080},
+						},
+					},
+				},
+			},
+		},
+		{
+			name: "replace ports on container",
+			existing: corev1.PodSpec{
+				Containers: []corev1.Container{
+					corev1.Container{
+						Name: "test",
+						Ports: []corev1.ContainerPort{
+							corev1.ContainerPort{ContainerPort: 8080},
+						},
+					},
+				},
+			},
+			input: corev1.PodSpec{
+				Containers: []corev1.Container{
+					corev1.Container{
+						Name: "test",
+						Ports: []corev1.ContainerPort{
+							corev1.ContainerPort{ContainerPort: 9191},
+						},
+					},
+				},
+			},
+			expectedModified: true,
+			expected: corev1.PodSpec{
+				Containers: []corev1.Container{
+					corev1.Container{
+						Name: "test",
+						Ports: []corev1.ContainerPort{
+							corev1.ContainerPort{ContainerPort: 9191},
+						},
+					},
+				},
+			},
+		},
+		{
+			name: "remove container ports",
+			existing: corev1.PodSpec{
+				Containers: []corev1.Container{
+					corev1.Container{
+						Name: "test",
+						Ports: []corev1.ContainerPort{
+							corev1.ContainerPort{ContainerPort: 8080},
+						},
+					},
+				},
+			},
+			input: corev1.PodSpec{
+				Containers: []corev1.Container{
+					corev1.Container{Name: "test"},
+				},
+			},
+			expectedModified: true,
+			expected: corev1.PodSpec{
+				Containers: []corev1.Container{
+					corev1.Container{
+						Name:  "test",
+						Ports: []corev1.ContainerPort{},
+					},
+				},
+			},
+		},
 	}
 
 	for _, test := range tests {
@@ -274,11 +386,11 @@ func TestEnsureServicePorts(t *testing.T) {
 		expected         corev1.Service
 	}{
 		{
-			name: "empty inputs",
-			existing: corev1.Service{},
-			input:    corev1.Service{},
+			name:             "empty inputs",
+			existing:         corev1.Service{},
+			input:            corev1.Service{},
 			expectedModified: false,
-			expected: corev1.Service{},
+			expected:         corev1.Service{},
 		},
 		{
 			name: "add port (no name)",
@@ -290,7 +402,7 @@ func TestEnsureServicePorts(t *testing.T) {
 					Ports: []corev1.ServicePort{
 						{
 							Protocol: corev1.ProtocolUDP,
-							Port: 8282,
+							Port:     8282,
 						},
 					},
 				},
@@ -301,7 +413,7 @@ func TestEnsureServicePorts(t *testing.T) {
 					Ports: []corev1.ServicePort{
 						{
 							Protocol: corev1.ProtocolUDP,
-							Port: 8282,
+							Port:     8282,
 						},
 					},
 				},
@@ -316,9 +428,9 @@ func TestEnsureServicePorts(t *testing.T) {
 				Spec: corev1.ServiceSpec{
 					Ports: []corev1.ServicePort{
 						{
-							Name: "foo",
+							Name:     "foo",
 							Protocol: corev1.ProtocolUDP,
-							Port: 8282,
+							Port:     8282,
 						},
 					},
 				},
@@ -328,9 +440,9 @@ func TestEnsureServicePorts(t *testing.T) {
 				Spec: corev1.ServiceSpec{
 					Ports: []corev1.ServicePort{
 						{
-							Name: "foo",
+							Name:     "foo",
 							Protocol: corev1.ProtocolUDP,
-							Port: 8282,
+							Port:     8282,
 						},
 					},
 				},
@@ -381,9 +493,9 @@ func TestEnsureServicePorts(t *testing.T) {
 				Spec: corev1.ServiceSpec{
 					Ports: []corev1.ServicePort{
 						{
-							Name: "test",
+							Name:     "test",
 							Protocol: corev1.ProtocolUDP,
-							Port: 8080,
+							Port:     8080,
 						},
 					},
 				},
@@ -392,9 +504,9 @@ func TestEnsureServicePorts(t *testing.T) {
 				Spec: corev1.ServiceSpec{
 					Ports: []corev1.ServicePort{
 						{
-							Name: "test",
+							Name:     "test",
 							Protocol: corev1.ProtocolUDP,
-							Port: 8282,
+							Port:     8282,
 						},
 					},
 				},
@@ -404,9 +516,9 @@ func TestEnsureServicePorts(t *testing.T) {
 				Spec: corev1.ServiceSpec{
 					Ports: []corev1.ServicePort{
 						{
-							Name: "test",
+							Name:     "test",
 							Protocol: corev1.ProtocolUDP,
-							Port: 8282,
+							Port:     8282,
 						},
 					},
 				},
@@ -428,7 +540,7 @@ func TestEnsureServicePorts(t *testing.T) {
 					Ports: []corev1.ServicePort{
 						{
 							Protocol: corev1.ProtocolUDP,
-							Port: 8282,
+							Port:     8282,
 						},
 					},
 				},
@@ -439,7 +551,7 @@ func TestEnsureServicePorts(t *testing.T) {
 					Ports: []corev1.ServicePort{
 						{
 							Protocol: corev1.ProtocolUDP,
-							Port: 8282,
+							Port:     8282,
 						},
 					},
 				},
@@ -465,14 +577,14 @@ func TestEnsureServicePorts(t *testing.T) {
 				Spec: corev1.ServiceSpec{
 					Ports: []corev1.ServicePort{
 						{
-							Name: "foo",
+							Name:     "foo",
 							Protocol: corev1.ProtocolUDP,
-							Port: 8282,
+							Port:     8282,
 						},
 						{
-							Name: "bar",
+							Name:     "bar",
 							Protocol: corev1.ProtocolUDP,
-							Port: 8283,
+							Port:     8283,
 						},
 					},
 				},
@@ -482,14 +594,14 @@ func TestEnsureServicePorts(t *testing.T) {
 				Spec: corev1.ServiceSpec{
 					Ports: []corev1.ServicePort{
 						{
-							Name: "foo",
+							Name:     "foo",
 							Protocol: corev1.ProtocolUDP,
-							Port: 8282,
+							Port:     8282,
 						},
 						{
-							Name: "bar",
+							Name:     "bar",
 							Protocol: corev1.ProtocolUDP,
-							Port: 8283,
+							Port:     8283,
 						},
 					},
 				},
@@ -501,14 +613,14 @@ func TestEnsureServicePorts(t *testing.T) {
 				Spec: corev1.ServiceSpec{
 					Ports: []corev1.ServicePort{
 						{
-							Name: "foo",
+							Name:     "foo",
 							Protocol: corev1.ProtocolUDP,
-							Port: 8080,
+							Port:     8080,
 						},
 						{
-							Name: "bar",
+							Name:     "bar",
 							Protocol: corev1.ProtocolUDP,
-							Port: 8081,
+							Port:     8081,
 						},
 					},
 				},
@@ -517,14 +629,14 @@ func TestEnsureServicePorts(t *testing.T) {
 				Spec: corev1.ServiceSpec{
 					Ports: []corev1.ServicePort{
 						{
-							Name: "bar",
+							Name:     "bar",
 							Protocol: corev1.ProtocolUDP,
-							Port: 8081,
+							Port:     8081,
 						},
 						{
-							Name: "foo",
+							Name:     "foo",
 							Protocol: corev1.ProtocolUDP,
-							Port: 8080,
+							Port:     8080,
 						},
 					},
 				},
@@ -534,14 +646,14 @@ func TestEnsureServicePorts(t *testing.T) {
 				Spec: corev1.ServiceSpec{
 					Ports: []corev1.ServicePort{
 						{
-							Name: "foo",
+							Name:     "foo",
 							Protocol: corev1.ProtocolUDP,
-							Port: 8080,
+							Port:     8080,
 						},
 						{
-							Name: "bar",
+							Name:     "bar",
 							Protocol: corev1.ProtocolUDP,
-							Port: 8081,
+							Port:     8081,
 						},
 					},
 				},
@@ -553,14 +665,14 @@ func TestEnsureServicePorts(t *testing.T) {
 				Spec: corev1.ServiceSpec{
 					Ports: []corev1.ServicePort{
 						{
-							Name: "foo",
-							Port: 8080,
+							Name:     "foo",
+							Port:     8080,
 							Protocol: corev1.ProtocolTCP,
 						},
 						{
-							Name: "bar",
+							Name:     "bar",
 							Protocol: corev1.ProtocolTCP,
-							Port: 8081,
+							Port:     8081,
 						},
 					},
 				},
@@ -584,14 +696,14 @@ func TestEnsureServicePorts(t *testing.T) {
 				Spec: corev1.ServiceSpec{
 					Ports: []corev1.ServicePort{
 						{
-							Name: "foo",
+							Name:     "foo",
 							Protocol: corev1.ProtocolTCP,
-							Port: 8080,
+							Port:     8080,
 						},
 						{
-							Name: "bar",
+							Name:     "bar",
 							Protocol: corev1.ProtocolTCP,
-							Port: 8081,
+							Port:     8081,
 						},
 					},
 				},
@@ -603,11 +715,11 @@ func TestEnsureServicePorts(t *testing.T) {
 				Spec: corev1.ServiceSpec{
 					Ports: []corev1.ServicePort{
 						{
-							Name: "foo",
-							Port: 8080,
+							Name:       "foo",
+							Port:       8080,
 							TargetPort: intstr.FromInt(8081),
-							NodePort: 8081,
-							Protocol: corev1.ProtocolTCP,
+							NodePort:   8081,
+							Protocol:   corev1.ProtocolTCP,
 						},
 					},
 				},
@@ -627,9 +739,9 @@ func TestEnsureServicePorts(t *testing.T) {
 				Spec: corev1.ServiceSpec{
 					Ports: []corev1.ServicePort{
 						{
-							Name: "foo",
+							Name:     "foo",
 							Protocol: corev1.ProtocolTCP,
-							Port: 8080,
+							Port:     8080,
 						},
 					},
 				},
